@@ -4,7 +4,7 @@ import (
 	"strings"
 	"time"
 
-	"k8s.io/kubernetes/pkg/kubectl/util/templates"
+	"k8s.io/kubectl/pkg/util/templates"
 
 	"github.com/openshift/origin/pkg/test/ginkgo"
 
@@ -105,7 +105,7 @@ var staticSuites = []*ginkgo.TestSuite{
 		Matches: func(name string) bool {
 			return strings.Contains(name, "[Feature:Jenkins]")
 		},
-		Parallelism: 3,
+		Parallelism: 4,
 		TestTimeout: 20 * time.Minute,
 	},
 	{
