@@ -15,6 +15,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/validation"
 	"k8s.io/apimachinery/pkg/util/wait"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
+	"k8s.io/kubernetes/test/e2e/framework/pod"
 
 	buildv1 "github.com/openshift/api/build/v1"
 	exutil "github.com/openshift/origin/test/extended/util"
@@ -86,7 +87,7 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 					e2e.DeletePersistentVolume(client, pv.Name)
 				}
 				g.By("removing nfs pod")
-				e2e.DeletePodWithWait(oc.AsAdmin().KubeFramework(), client, nfspod)
+				pod.DeletePodWithWait(client, nfspod)
 			}
 		}
 		setupJenkins = func(jenkinsTemplatePath string) {
@@ -253,8 +254,7 @@ var _ = g.Describe("[Feature:Builds][Feature:Jenkins][Slow] openshift pipeline b
 				o.Expect(err).NotTo(o.HaveOccurred())
 				err = oc.Run("delete").Args("is", "ruby").Execute()
 				o.Expect(err).NotTo(o.HaveOccurred())
-				// TODO: Update to ruby 2.5
-				err = oc.Run("delete").Args("is", "ruby-22-centos7").Execute()
+				err = oc.Run("delete").Args("is", "ruby-25-centos7").Execute()
 				o.Expect(err).NotTo(o.HaveOccurred())
 
 				// doing this as admin to avoid errors like this:
